Satellite

Struct Satellite 

pub struct Satellite {
    pub prn: i16,
    pub elevation: Option<f32>,
    pub azimuth: Option<f32>,
    pub ss: Option<f32>,
    pub used: bool,
    pub gnss_id: Option<u8>,
    pub satellite_id: Option<u8>,
    pub signal_id: Option<u8>,
    pub freq_id: Option<u8>,
    pub health: Option<u8>,
}
Satellite object.

Fields

prn: i16

PRN ID of the satellite.

See “PRN, GNSS id, SV id, and SIG id”

elevation: Option<f32>

Elevation in degrees.

azimuth: Option<f32>

Azimuth, degrees from true north.

ss: Option<f32>

Signal to Noise ratio in dBHz.

used: bool

Used in current solution?

(SBAS/WAAS/EGNOS satellites may be flagged used if the solution has corrections from them, but not all drivers make this information available.)

gnss_id: Option<u8>

The GNSS ID.

See “PRN, GNSS id, SV id, and SIG id”

satellite_id: Option<u8>

The satellite ID (PRN) within its constellation.

signal_id: Option<u8>

The signal ID of this signal.

See “PRN, GNSS id, SV id, and SIG id” u-blox, not NMEA. See u-blox doc for details.

freq_id: Option<u8>

For GLONASS satellites only: the frequency ID of the signal.

As defined by u-blox, range 0 to 13. The freqid is the frequency slot plus 7.

health: Option<u8>

The health of this satellite. 0 is unknown, 1 is OK, and 2 is unhealthy.